@@ -83,7 +83,7 @@ void d_fail(const char *str, ...) {
   va_list ap;
   va_start(ap, str);
   snprintf(nstr, 255, "Parser Fail: %s", str);
-  vsprintf(outstr, nstr, ap);
+  vsnprintf(outstr, 256*2, nstr, ap);
   va_end(ap);
   error(outstr);
 }
@@ -94,7 +94,7 @@ void d_warn(const char *str, ...) {
   va_list ap;
   va_start(ap, str);
   snprintf(nstr, 255, "%s", str);
-  vsprintf(outstr, nstr, ap);
+  vsnprintf(outstr, 256*2, nstr, ap);
   va_end(ap);
   warning(outstr);
 }
